import React from 'react';
import { Meta } from '@storybook/react';
import { graphQueryResultSlice, querybuilderSlice, schemaSlice, visualizationSlice } from '../../../data-access/store';
import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';
import { mockLargeQueryResults } from '../../../mock-data/query-result';
import RawJSONComponent from './rawjsonvis';

const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
    visualize: visualizationSlice.reducer,
    querybuilder: querybuilderSlice.reducer,
  },
});

const Component: Meta<typeof RawJSONComponent.component> = {
  title: 'Visualizations/RawJSONVIS',
  component: RawJSONComponent.component,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

export const SimpleData = {
  args: {
    data: {
      nodes: [
        { id: 'agent/007', attributes: { name: 'Daniel Craig' } },
        { id: 'villain', attributes: { name: 'Le Chiffre' } },
      ],
      edges: [],
    },
    configuration: RawJSONComponent.configuration,
  },
};

export const LargeData = {
  args: {
    data: mockLargeQueryResults,
    configuration: RawJSONComponent.configuration,
  },
};

export const Empty = {
  args: {
    data: {
      nodes: [],
      edges: [],
    },
    configuration: RawJSONComponent.configuration,
  },
};

export default Component;
